//----------------------------------------------------------------------------------
//
// Sensirion SHTxx Humidity Sensor Library
//
// Library for using the SHT1x humidity and temperature
// sensors from Sensirion (http://www.sensirion.com).
// Based on Sensirion application note "Sample Code SHTxx", adapted by
//          Brian Low (mportobello@hotmail.com)
//
// History:
// 2003-Jul-03  BL  - Created
// 2005-Mar-05  bue - Adapted by Daniel Buergin
//
//----------------------------------------------------------------------------------

#ifndef __sht75_h
#define __sht75_h
#include <avr/io.h> 

//#include "main.h"

#define SHT_TEMPERATURE 	0x03		// Measure temp - for ShtMeasure
#define SHT_HUMIDITY 		0x05		// Measure humidity - for ShtMeasure

#define SHT_DDR			DDRD		// Port with clock and data pins
#define SHT_PORT		PORTD		// Port with clock and data pins
#define SHT_PIN			PIND		// Port with clock and data pins
#define SHT_CLOCK		0		// Pin used to output clock to SHT
#define SHT_DATA		1		// Pin used to read/output data from/to SHT

#define SHT_DELAY		25		// uS delay between clock rise/fall

#define STATUS_REG_W 		0x06 		// Command to read status register
#define STATUS_REG_R 		0x07 		// Command to write status register
#define RESET 			0x1e 		// Command for soft reset (not currently used)

// Struct for the Data from the Sensor

typedef struct sht75st
{
	double Temperature;
	double Humidity;
	double Dewpoint;
} sht75_array;

void wait_ms(uint16_t ms);
void ShtInit(void);
void ShtReset(void);
int  ShtMeasure(unsigned char mode);
void ShtReadEverything(sht75_array *sht75_struct);
char ShtReadStatus(unsigned char *p_value);
// char ShtWriteStatus(unsigned char value);

unsigned int Sht_start_Temp(void);
unsigned int Sht_start_Humi(void);
double Sht_calc_temp(unsigned int T );
double Sht_calc_humi(unsigned int RH,double Temp);
unsigned int Sht_read(void);
unsigned int Sht_ready(void);

#endif
